aboutsummaryrefslogtreecommitdiff
path: root/libs/nak/src/paths.rs
diff options
context:
space:
mode:
Diffstat (limited to 'libs/nak/src/paths.rs')
-rw-r--r--libs/nak/src/paths.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/libs/nak/src/paths.rs b/libs/nak/src/paths.rs
index e86c284..f6dde6c 100644
--- a/libs/nak/src/paths.rs
+++ b/libs/nak/src/paths.rs
@@ -1,11 +1,11 @@
//! Shared data directory for Fluorine Manager.
//!
//! All data lives under `~/.var/app/com.fluorine.manager/`.
use std::path::PathBuf;
/// Returns the Fluorine data directory (`~/.var/app/com.fluorine.manager`).
pub fn data_dir() -> PathBuf {
let home = std::env::var("HOME").unwrap_or_else(|_| "/tmp".to_string());
- PathBuf::from(home).join(".var/app/com.fluorine.manager")
+ PathBuf::from(home).join(".local/share/fluorine")
}
@@ -1,11 +1,11 @@
//! Shared data directory for Fluorine Manager.
//!
-//! All data lives under `~/.var/app/com.fluorine.manager/`.
+//! All data lives under `~/.local/share/fluorine/`.
use std::path::PathBuf;
@@ -1,11 +1,11 @@
use std::path::PathBuf;
-/// Returns the Fluorine data directory (`~/.var/app/com.fluorine.manager`).
+/// Returns the Fluorine data directory (`~/.local/share/fluorine`).
pub fn data_dir() -> PathBuf {
let home = std::env::var("HOME").unwrap_or_else(|_| "/tmp".to_string());